oauth2client
============

This is a client library for accessing resources protected by OAuth 2.0.

**Note**: oauth2client is now deprecated. No more features will be added to the
libraries and the core team is turning down support. We recommend you use
[google-auth](https://google-auth.readthedocs.io) and [oauthlib](http://oauthlib.readthedocs.io/). For more details on the deprecation, see [oauth2client deprecation](https://google-auth.readthedocs.io/en/latest/oauth2client-deprecation.html).

Installation
============

To install, simply run the following command in your terminal:

```bash
$ pip install --upgrade internationaltouch-oauth2client
```

Supported Python Versions
=========================

We plan to support Python 3.6+ as required.

[1]: https://github.com/internationaltouch/oauth2client/blob/master/CONTRIBUTING.md
